@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef DAP_ENTITIES_H
-#define DAP_ENTITIES_H
+#pragma once
 
 #include <QHash>
 #include <QJsonValue>
@@ -445,6 +444,11 @@ struct Variable {
      */
     std::optional<QString> memoryReference;
 
+    /**
+     * the value has changed since the last time
+     */
+    std::optional<bool> valueChanged;
+
     Variable() = default;
     Variable(const QJsonObject &body);
     Variable(const QString &name, const QString &value, const int reference = 0);
@@ -480,5 +484,3 @@ struct GotoTarget {
 };
 
 }
-
-#endif // DAP_ENTITIES_H
