@@ -9,6 +9,8 @@
 #include "hostprocess.h"
 #include "lspclient_debug.h"
 
+#include "ktexteditor_utils.h"
+
 #include <QCoreApplication>
 #include <QFileInfo>
 #include <QJsonArray>
@@ -490,27 +492,10 @@ static void from_json(LSPServerCapabilities &caps, const rapidjson::Value &json)
     caps.inlayHintProvider = json.HasMember("inlayHintProvider");
 }
 
-// follow suit; as performed in kate docmanager
-// normalize at this stage/layer to avoid surprises elsewhere
-// sadly this is not a single QUrl method as one might hope ...
-static QUrl normalizeUrl(const QUrl &url)
-{
-    // Resolve symbolic links for local files (done anyway in KTextEditor)
-    if (url.isLocalFile()) {
-        QString normalizedUrl = QFileInfo(url.toLocalFile()).canonicalFilePath();
-        if (!normalizedUrl.isEmpty()) {
-            return QUrl::fromLocalFile(normalizedUrl);
-        }
-    }
-
-    // else: cleanup only the .. stuff
-    return url.adjusted(QUrl::NormalizePathSegments);
-}
-
 static void from_json(LSPVersionedTextDocumentIdentifier &id, const rapidjson::Value &json)
 {
     if (json.IsObject()) {
-        id.uri = normalizeUrl(QUrl(GetStringValue(json, MEMBER_URI)));
+        id.uri = Utils::normalizeUrl(QUrl(GetStringValue(json, MEMBER_URI)));
         id.version = GetIntValue(json, MEMBER_VERSION, -1);
     }
 }
@@ -593,20 +578,18 @@ static QList<std::shared_ptr<LSPSelectionRange>> parseSelectionRanges(const rapi
     if (!result.IsArray()) {
         return ret;
     }
-    auto selectionRanges = result.GetArray();
-    for (const auto &selectionRange : selectionRanges) {
+    ret.reserve(result.Size());
+    for (const auto &selectionRange : result.GetArray()) {
         ret.push_back(parseSelectionRange(selectionRange));
     }
-
     return ret;
 }
 
 static LSPLocation parseLocation(const rapidjson::Value &loc)
 {
-    auto uri = normalizeUrl(QUrl(GetStringValue(loc, MEMBER_URI)));
+    auto uri = Utils::normalizeUrl(QUrl(GetStringValue(loc, MEMBER_URI)));
     KTextEditor::Range range;
-    auto it = loc.FindMember(MEMBER_RANGE);
-    if (it != loc.MemberEnd()) {
+    if (auto it = loc.FindMember(MEMBER_RANGE); it != loc.MemberEnd()) {
         range = parseRange(it->value);
     }
     return {QUrl(uri), range};
@@ -615,14 +598,14 @@ static LSPLocation parseLocation(const rapidjson::Value &loc)
 static LSPLocation parseLocationLink(const rapidjson::Value &loc)
 {
     auto urlString = GetStringValue(loc, MEMBER_TARGET_URI);
-    auto uri = normalizeUrl(QUrl(urlString));
+    auto uri = Utils::normalizeUrl(QUrl(urlString));
     // both should be present, selection contained by the other
     // so let's preferentially pick the smallest one
     KTextEditor::Range range;
-    if (loc.HasMember(MEMBER_TARGET_SELECTION_RANGE)) {
-        range = parseRange(loc[MEMBER_TARGET_SELECTION_RANGE]);
-    } else {
-        range = parseRange(loc[MEMBER_TARGET_RANGE]);
+    if (auto it = loc.FindMember(MEMBER_TARGET_SELECTION_RANGE); it != loc.MemberEnd()) {
+        range = parseRange(it->value);
+    } else if (auto it = loc.FindMember(MEMBER_TARGET_RANGE); it != loc.MemberEnd()) {
+        range = parseRange(it->value);
     }
     return {QUrl(uri), range};
 }
@@ -630,6 +613,9 @@ static LSPLocation parseLocationLink(const rapidjson::Value &loc)
 static QList<LSPTextEdit> parseTextEdit(const rapidjson::Value &result)
 {
     QList<LSPTextEdit> ret;
+    if (!result.IsArray()) {
+        return ret;
+    }
     ret.reserve(result.Size());
     for (const auto &edit : result.GetArray()) {
         auto text = GetStringValue(edit, "newText");
@@ -951,7 +937,7 @@ static LSPWorkspaceEdit parseWorkSpaceEdit(const rapidjson::Value &result)
     const auto &changes = GetJsonObjectForKey(result, "changes");
     for (const auto &change : changes.GetObject()) {
         auto url = QString::fromUtf8(change.name.GetString());
-        ret.changes.insert(normalizeUrl(QUrl(url)), parseTextEdit(change.value.GetArray()));
+        ret.changes.insert(Utils::normalizeUrl(QUrl(url)), parseTextEdit(change.value.GetArray()));
     }
 
     const auto &documentChanges = GetJsonArrayForKey(result, "documentChanges");
