@@ -7,6 +7,7 @@
 
 #include "diagnosticitem.h"
 #include "drawing_utils.h"
+#include "kateapp.h"
 #include "kateviewmanager.h"
 #include "session_diagnostic_suppression.h"
 #include "texthint/KateTextHintManager.h"
@@ -18,6 +19,7 @@
 #include <KTextEditor/MainWindow>
 
 #include <KColorScheme>
+#include <KMessageWidget>
 #include <KXMLGUIFactory>
 #include <QClipboard>
 #include <QComboBox>
@@ -277,6 +279,7 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     , m_providerCombo(new QComboBox(this))
     , m_errFilterBtn(new QToolButton(this))
     , m_warnFilterBtn(new QToolButton(this))
+    , m_diagLimitReachedWarning(new KMessageWidget(this))
     , m_proxy(new DiagnosticsProxyModel(this))
     , m_sessionDiagnosticSuppressions(std::make_unique<SessionDiagnosticSuppressions>())
     , m_posChangedTimer(new QTimer(this))
@@ -290,6 +293,14 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     auto l = new QVBoxLayout(this);
     l->setContentsMargins({});
     setupDiagnosticViewToolbar(l);
+
+    m_diagLimitReachedWarning->setText(i18n("Diagnostics limit reached, ignoring further diagnostics. The limit can be configured in settings."));
+    m_diagLimitReachedWarning->setWordWrap(true);
+    m_diagLimitReachedWarning->setCloseButtonVisible(false);
+    m_diagLimitReachedWarning->setMessageType(KMessageWidget::Warning);
+    l->addWidget(m_diagLimitReachedWarning);
+    m_diagLimitReachedWarning->hide(); // hidden by default
+
     l->addWidget(m_diagnosticsTree);
 
     m_filterChangedTimer->setInterval(400);
@@ -385,6 +396,19 @@ DiagnosticsView::DiagnosticsView(QWidget *parent, KTextEditor::MainWindow *mainW
     // manager has been initialized.
     ac->clearAssociatedWidgets();
     ac->addAssociatedWidget(this);
+
+    auto readConfig = [this] {
+        KSharedConfig::Ptr config = KSharedConfig::openConfig();
+        KConfigGroup cgGeneral = KConfigGroup(config, QStringLiteral("General"));
+        m_diagnosticLimit = cgGeneral.readEntry("Diagnostics Limit", 12000);
+
+        const bool diagnosticsAreLimited = m_diagnosticLimit > -1;
+        if (!diagnosticsAreLimited && m_diagLimitReachedWarning->isVisible()) {
+            m_diagLimitReachedWarning->hide();
+        }
+    };
+    connect(KateApp::self(), &KateApp::configurationChanged, this, readConfig);
+    readConfig();
 }
 
 DiagnosticsView *DiagnosticsView::instance(KTextEditor::MainWindow *mainWindow)
@@ -483,6 +507,7 @@ void DiagnosticsView::setupDiagnosticViewToolbar(QVBoxLayout *mainLayout)
         }
         m_model.clear();
         m_diagnosticsCount = 0;
+        m_diagLimitReachedWarning->hide();
     });
     l->addWidget(m_clearButton);
 }
@@ -785,10 +810,24 @@ void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
     // and the user doesn't know about it and thus won't get any further diagnostics at all while typing
     const bool diagnosticsAreForActiveDoc = doc ? diagnostics.uri == doc->url() : false;
 
-    if (m_diagnosticsCount > 12000 && !diagnosticsAreForActiveDoc) {
+    const bool diagnosticsAreLimited = m_diagnosticLimit > -1;
+    if (diagnosticsAreLimited && m_diagnosticsCount > m_diagnosticLimit && !diagnosticsAreForActiveDoc) {
         return;
     }
 
+    auto diagWarnShowGuard = qScopeGuard([this] {
+        const bool diagnosticsAreLimited = m_diagnosticLimit > -1;
+        if (!diagnosticsAreLimited) {
+            return;
+        }
+
+        if (m_diagnosticsCount > m_diagnosticLimit && !m_diagLimitReachedWarning->isVisible()) {
+            m_diagLimitReachedWarning->show();
+        } else if (m_diagnosticsCount < m_diagnosticLimit && m_diagLimitReachedWarning->isVisible()) {
+            m_diagLimitReachedWarning->hide();
+        }
+    });
+
     auto *provider = qobject_cast<DiagnosticsProvider *>(sender());
     Q_ASSERT(provider);
 
@@ -825,6 +864,8 @@ void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
         }
     }
     topItem->addProvider(provider);
+    // emit so that proxy can update
+    m_model.dataChanged(topItem->index(), topItem->index());
 
     QList<QStandardItem *> diagItems;
     diagItems.reserve(diagnostics.diagnostics.size());
@@ -901,6 +942,17 @@ static auto getProvider(QStandardItem *item)
 
 void DiagnosticsView::clearDiagnosticsForStaleDocs(const QList<QString> &filesToKeep, DiagnosticsProvider *provider)
 {
+    auto diagWarnShowGuard = qScopeGuard([this] {
+        const bool diagnosticsAreLimited = m_diagnosticLimit > -1;
+        if (!diagnosticsAreLimited) {
+            return;
+        }
+
+        if (m_diagnosticsCount < m_diagnosticLimit && m_diagLimitReachedWarning->isVisible()) {
+            m_diagLimitReachedWarning->hide();
+        }
+    });
+
     auto all_diags_from_provider = [provider](DocumentDiagnosticItem *file) {
         if (file->rowCount() == 0) {
             return true;
